<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RestrictOff</name>
    <message>
        <location filename="../RestrictOffInit.js" line="+2"/>
        <source>Restrictions &amp;Off</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wyłączenie ograniczania</translation>
    </message>
</context>
</TS>
